@@ -18,22 +18,22 @@ class IPBlocksApi(object):
         self.api_client = api_client
 
     def ipblocks_delete(self, ipblock_id, **kwargs):  # noqa: E501
-        """Delete IP Block  # noqa: E501
+        """Delete IP blocks  # noqa: E501
 
-        Removes the specific IP Block  # noqa: E501
+        Remove the specified IP block.  # noqa: E501
         This method makes a synchronous HTTP request by default. To make an
         asynchronous HTTP request, please pass async_req=True
 
         >>> thread = api.ipblocks_delete(ipblock_id, async_req=True)
         >>> result = thread.get()
 
-        :param ipblock_id: (required)
+        :param ipblock_id: The unique ID of the IP block. (required)
         :type ipblock_id: str
-        :param pretty: Controls whether response is pretty-printed (with indentation and new lines)
+        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
         :type pretty: bool
-        :param depth: Controls the details depth of response objects.  Eg. GET /datacenters/[ID]  - depth=0: only direct properties are included. Children (servers etc.) are not included  - depth=1: direct properties and children references are included  - depth=2: direct properties and children properties are included  - depth=3: direct properties and children properties and children's children are included  - depth=... and so on
+        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
         :type depth: int
-        :param x_contract_number: Users having more than 1 contract need to provide contract number, against which all API requests should be executed
+        :param x_contract_number: Users with multiple contracts must provide the contract number, against which all API requests are to be executed.
         :type x_contract_number: int
         :param async_req: Whether to execute the request asynchronously.
         :type async_req: bool, optional
@@ -48,28 +48,28 @@ class IPBlocksApi(object):
         :return: Returns the result object.
                  If the method is called asynchronously,
                  returns the request thread.
-        :rtype: object
+        :rtype: None
         """
         kwargs['_return_http_data_only'] = True
         return self.ipblocks_delete_with_http_info(ipblock_id, **kwargs)  # noqa: E501
 
     def ipblocks_delete_with_http_info(self, ipblock_id, **kwargs):  # noqa: E501
-        """Delete IP Block  # noqa: E501
+        """Delete IP blocks  # noqa: E501
 
-        Removes the specific IP Block  # noqa: E501
+        Remove the specified IP block.  # noqa: E501
         This method makes a synchronous HTTP request by default. To make an
         asynchronous HTTP request, please pass async_req=True
 
         >>> thread = api.ipblocks_delete_with_http_info(ipblock_id, async_req=True)
         >>> result = thread.get()
 
-        :param ipblock_id: (required)
+        :param ipblock_id: The unique ID of the IP block. (required)
         :type ipblock_id: str
-        :param pretty: Controls whether response is pretty-printed (with indentation and new lines)
+        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
         :type pretty: bool
-        :param depth: Controls the details depth of response objects.  Eg. GET /datacenters/[ID]  - depth=0: only direct properties are included. Children (servers etc.) are not included  - depth=1: direct properties and children references are included  - depth=2: direct properties and children properties are included  - depth=3: direct properties and children properties and children's children are included  - depth=... and so on
+        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
         :type depth: int
-        :param x_contract_number: Users having more than 1 contract need to provide contract number, against which all API requests should be executed
+        :param x_contract_number: Users with multiple contracts must provide the contract number, against which all API requests are to be executed.
         :type x_contract_number: int
         :param async_req: Whether to execute the request asynchronously.
         :type async_req: bool, optional
@@ -91,7 +91,7 @@ class IPBlocksApi(object):
         :return: Returns the result object.
                  If the method is called asynchronously,
                  returns the request thread.
-        :rtype: tuple(object, status_code(int), headers(HTTPHeaderDict))
+        :rtype: None
         """
 
         local_var_params = locals()
@@ -157,7 +157,7 @@ class IPBlocksApi(object):
         # Authentication setting
         auth_settings = ['Basic Authentication', 'Token Authentication']  # noqa: E501
 
-        response_type = 'object'
+        response_type = None
         if 'response_type' in kwargs:
             response_type = kwargs['response_type']
 
@@ -179,22 +179,22 @@ class IPBlocksApi(object):
             _request_auth=local_var_params.get('_request_auth'))
 
     def ipblocks_find_by_id(self, ipblock_id, **kwargs):  # noqa: E501
-        """Retrieve an IP Block  # noqa: E501
+        """Retrieve IP blocks  # noqa: E501
 
-        Retrieves the attributes of a given IP Block.  # noqa: E501
+        Retrieve the properties of the specified IP block.  # noqa: E501
         This method makes a synchronous HTTP request by default. To make an
         asynchronous HTTP request, please pass async_req=True
 
         >>> thread = api.ipblocks_find_by_id(ipblock_id, async_req=True)
         >>> result = thread.get()
 
-        :param ipblock_id: (required)
+        :param ipblock_id: The unique ID of the IP block. (required)
         :type ipblock_id: str
-        :param pretty: Controls whether response is pretty-printed (with indentation and new lines)
+        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
         :type pretty: bool
-        :param depth: Controls the details depth of response objects.  Eg. GET /datacenters/[ID]  - depth=0: only direct properties are included. Children (servers etc.) are not included  - depth=1: direct properties and children references are included  - depth=2: direct properties and children properties are included  - depth=3: direct properties and children properties and children's children are included  - depth=... and so on
+        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
         :type depth: int
-        :param x_contract_number: Users having more than 1 contract need to provide contract number, against which all API requests should be executed
+        :param x_contract_number: Users with multiple contracts must provide the contract number, against which all API requests are to be executed.
         :type x_contract_number: int
         :param async_req: Whether to execute the request asynchronously.
         :type async_req: bool, optional
@@ -215,22 +215,22 @@ class IPBlocksApi(object):
         return self.ipblocks_find_by_id_with_http_info(ipblock_id, **kwargs)  # noqa: E501
 
     def ipblocks_find_by_id_with_http_info(self, ipblock_id, **kwargs):  # noqa: E501
-        """Retrieve an IP Block  # noqa: E501
+        """Retrieve IP blocks  # noqa: E501
 
-        Retrieves the attributes of a given IP Block.  # noqa: E501
+        Retrieve the properties of the specified IP block.  # noqa: E501
         This method makes a synchronous HTTP request by default. To make an
         asynchronous HTTP request, please pass async_req=True
 
         >>> thread = api.ipblocks_find_by_id_with_http_info(ipblock_id, async_req=True)
         >>> result = thread.get()
 
-        :param ipblock_id: (required)
+        :param ipblock_id: The unique ID of the IP block. (required)
         :type ipblock_id: str
-        :param pretty: Controls whether response is pretty-printed (with indentation and new lines)
+        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
         :type pretty: bool
-        :param depth: Controls the details depth of response objects.  Eg. GET /datacenters/[ID]  - depth=0: only direct properties are included. Children (servers etc.) are not included  - depth=1: direct properties and children references are included  - depth=2: direct properties and children properties are included  - depth=3: direct properties and children properties and children's children are included  - depth=... and so on
+        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
         :type depth: int
-        :param x_contract_number: Users having more than 1 contract need to provide contract number, against which all API requests should be executed
+        :param x_contract_number: Users with multiple contracts must provide the contract number, against which all API requests are to be executed.
         :type x_contract_number: int
         :param async_req: Whether to execute the request asynchronously.
         :type async_req: bool, optional
@@ -340,24 +340,24 @@ class IPBlocksApi(object):
             _request_auth=local_var_params.get('_request_auth'))
 
     def ipblocks_get(self, **kwargs):  # noqa: E501
-        """List IP Blocks   # noqa: E501
+        """List IP blocks   # noqa: E501
 
-        Retrieve a list of all reserved IP Blocks  # noqa: E501
+        List all reserved IP blocks.  # noqa: E501
         This method makes a synchronous HTTP request by default. To make an
         asynchronous HTTP request, please pass async_req=True
 
         >>> thread = api.ipblocks_get(async_req=True)
         >>> result = thread.get()
 
-        :param pretty: Controls whether response is pretty-printed (with indentation and new lines)
+        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
         :type pretty: bool
-        :param depth: Controls the details depth of response objects.  Eg. GET /datacenters/[ID]  - depth=0: only direct properties are included. Children (servers etc.) are not included  - depth=1: direct properties and children references are included  - depth=2: direct properties and children properties are included  - depth=3: direct properties and children properties and children's children are included  - depth=... and so on
+        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
         :type depth: int
-        :param x_contract_number: Users having more than 1 contract need to provide contract number, against which all API requests should be executed
+        :param x_contract_number: Users with multiple contracts must provide the contract number, against which all API requests are to be executed.
         :type x_contract_number: int
-        :param offset: the first element (of the total list of elements) to include in the response (use together with <code>limit</code> for pagination)
+        :param offset: The first element (from the complete list of the elements) to include in the response (use together with limit for pagination).
         :type offset: int
-        :param limit: the maximum number of elements to return (use together with offset for pagination)
+        :param limit: The maximum number of elements to return (use together with offset for pagination).
         :type limit: int
         :param async_req: Whether to execute the request asynchronously.
         :type async_req: bool, optional
@@ -378,24 +378,24 @@ class IPBlocksApi(object):
         return self.ipblocks_get_with_http_info(**kwargs)  # noqa: E501
 
     def ipblocks_get_with_http_info(self, **kwargs):  # noqa: E501
-        """List IP Blocks   # noqa: E501
+        """List IP blocks   # noqa: E501
 
-        Retrieve a list of all reserved IP Blocks  # noqa: E501
+        List all reserved IP blocks.  # noqa: E501
         This method makes a synchronous HTTP request by default. To make an
         asynchronous HTTP request, please pass async_req=True
 
         >>> thread = api.ipblocks_get_with_http_info(async_req=True)
         >>> result = thread.get()
 
-        :param pretty: Controls whether response is pretty-printed (with indentation and new lines)
+        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
         :type pretty: bool
-        :param depth: Controls the details depth of response objects.  Eg. GET /datacenters/[ID]  - depth=0: only direct properties are included. Children (servers etc.) are not included  - depth=1: direct properties and children references are included  - depth=2: direct properties and children properties are included  - depth=3: direct properties and children properties and children's children are included  - depth=... and so on
+        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
         :type depth: int
-        :param x_contract_number: Users having more than 1 contract need to provide contract number, against which all API requests should be executed
+        :param x_contract_number: Users with multiple contracts must provide the contract number, against which all API requests are to be executed.
         :type x_contract_number: int
-        :param offset: the first element (of the total list of elements) to include in the response (use together with <code>limit</code> for pagination)
+        :param offset: The first element (from the complete list of the elements) to include in the response (use together with limit for pagination).
         :type offset: int
-        :param limit: the maximum number of elements to return (use together with offset for pagination)
+        :param limit: The maximum number of elements to return (use together with offset for pagination).
         :type limit: int
         :param async_req: Whether to execute the request asynchronously.
         :type async_req: bool, optional
@@ -510,24 +510,24 @@ class IPBlocksApi(object):
             _request_auth=local_var_params.get('_request_auth'))
 
     def ipblocks_patch(self, ipblock_id, ipblock, **kwargs):  # noqa: E501
-        """Partially modify IP Block  # noqa: E501
+        """Partially modify IP blocks  # noqa: E501
 
-        You can use update attributes of a resource  # noqa: E501
+        Update the properties of the specified IP block.  # noqa: E501
         This method makes a synchronous HTTP request by default. To make an
         asynchronous HTTP request, please pass async_req=True
 
         >>> thread = api.ipblocks_patch(ipblock_id, ipblock, async_req=True)
         >>> result = thread.get()
 
-        :param ipblock_id: (required)
+        :param ipblock_id: The unique ID of the IP block. (required)
         :type ipblock_id: str
-        :param ipblock: IP Block to be modified (required)
+        :param ipblock: The properties of the IP block to be updated. (required)
         :type ipblock: IpBlockProperties
-        :param pretty: Controls whether response is pretty-printed (with indentation and new lines)
+        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
         :type pretty: bool
-        :param depth: Controls the details depth of response objects.  Eg. GET /datacenters/[ID]  - depth=0: only direct properties are included. Children (servers etc.) are not included  - depth=1: direct properties and children references are included  - depth=2: direct properties and children properties are included  - depth=3: direct properties and children properties and children's children are included  - depth=... and so on
+        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
         :type depth: int
-        :param x_contract_number: Users having more than 1 contract need to provide contract number, against which all API requests should be executed
+        :param x_contract_number: Users with multiple contracts must provide the contract number, against which all API requests are to be executed.
         :type x_contract_number: int
         :param async_req: Whether to execute the request asynchronously.
         :type async_req: bool, optional
@@ -548,24 +548,24 @@ class IPBlocksApi(object):
         return self.ipblocks_patch_with_http_info(ipblock_id, ipblock, **kwargs)  # noqa: E501
 
     def ipblocks_patch_with_http_info(self, ipblock_id, ipblock, **kwargs):  # noqa: E501
-        """Partially modify IP Block  # noqa: E501
+        """Partially modify IP blocks  # noqa: E501
 
-        You can use update attributes of a resource  # noqa: E501
+        Update the properties of the specified IP block.  # noqa: E501
         This method makes a synchronous HTTP request by default. To make an
         asynchronous HTTP request, please pass async_req=True
 
         >>> thread = api.ipblocks_patch_with_http_info(ipblock_id, ipblock, async_req=True)
         >>> result = thread.get()
 
-        :param ipblock_id: (required)
+        :param ipblock_id: The unique ID of the IP block. (required)
         :type ipblock_id: str
-        :param ipblock: IP Block to be modified (required)
+        :param ipblock: The properties of the IP block to be updated. (required)
         :type ipblock: IpBlockProperties
-        :param pretty: Controls whether response is pretty-printed (with indentation and new lines)
+        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
         :type pretty: bool
-        :param depth: Controls the details depth of response objects.  Eg. GET /datacenters/[ID]  - depth=0: only direct properties are included. Children (servers etc.) are not included  - depth=1: direct properties and children references are included  - depth=2: direct properties and children properties are included  - depth=3: direct properties and children properties and children's children are included  - depth=... and so on
+        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
         :type depth: int
-        :param x_contract_number: Users having more than 1 contract need to provide contract number, against which all API requests should be executed
+        :param x_contract_number: Users with multiple contracts must provide the contract number, against which all API requests are to be executed.
         :type x_contract_number: int
         :param async_req: Whether to execute the request asynchronously.
         :type async_req: bool, optional
@@ -686,22 +686,22 @@ class IPBlocksApi(object):
             _request_auth=local_var_params.get('_request_auth'))
 
     def ipblocks_post(self, ipblock, **kwargs):  # noqa: E501
-        """Reserve IP Block  # noqa: E501
+        """Reserve IP blocks  # noqa: E501
 
-        This will reserve a new IP Block  # noqa: E501
+        Reserve a new IP block.  # noqa: E501
         This method makes a synchronous HTTP request by default. To make an
         asynchronous HTTP request, please pass async_req=True
 
         >>> thread = api.ipblocks_post(ipblock, async_req=True)
         >>> result = thread.get()
 
-        :param ipblock: IP Block to be reserved (required)
+        :param ipblock: The IP block to be reserved. (required)
         :type ipblock: IpBlock
-        :param pretty: Controls whether response is pretty-printed (with indentation and new lines)
+        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
         :type pretty: bool
-        :param depth: Controls the details depth of response objects.  Eg. GET /datacenters/[ID]  - depth=0: only direct properties are included. Children (servers etc.) are not included  - depth=1: direct properties and children references are included  - depth=2: direct properties and children properties are included  - depth=3: direct properties and children properties and children's children are included  - depth=... and so on
+        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
         :type depth: int
-        :param x_contract_number: Users having more than 1 contract need to provide contract number, against which all API requests should be executed
+        :param x_contract_number: Users with multiple contracts must provide the contract number, against which all API requests are to be executed.
         :type x_contract_number: int
         :param async_req: Whether to execute the request asynchronously.
         :type async_req: bool, optional
@@ -722,22 +722,22 @@ class IPBlocksApi(object):
         return self.ipblocks_post_with_http_info(ipblock, **kwargs)  # noqa: E501
 
     def ipblocks_post_with_http_info(self, ipblock, **kwargs):  # noqa: E501
-        """Reserve IP Block  # noqa: E501
+        """Reserve IP blocks  # noqa: E501
 
-        This will reserve a new IP Block  # noqa: E501
+        Reserve a new IP block.  # noqa: E501
         This method makes a synchronous HTTP request by default. To make an
         asynchronous HTTP request, please pass async_req=True
 
         >>> thread = api.ipblocks_post_with_http_info(ipblock, async_req=True)
         >>> result = thread.get()
 
-        :param ipblock: IP Block to be reserved (required)
+        :param ipblock: The IP block to be reserved. (required)
         :type ipblock: IpBlock
-        :param pretty: Controls whether response is pretty-printed (with indentation and new lines)
+        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
         :type pretty: bool
-        :param depth: Controls the details depth of response objects.  Eg. GET /datacenters/[ID]  - depth=0: only direct properties are included. Children (servers etc.) are not included  - depth=1: direct properties and children references are included  - depth=2: direct properties and children properties are included  - depth=3: direct properties and children properties and children's children are included  - depth=... and so on
+        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
         :type depth: int
-        :param x_contract_number: Users having more than 1 contract need to provide contract number, against which all API requests should be executed
+        :param x_contract_number: Users with multiple contracts must provide the contract number, against which all API requests are to be executed.
         :type x_contract_number: int
         :param async_req: Whether to execute the request asynchronously.
         :type async_req: bool, optional
@@ -851,24 +851,24 @@ class IPBlocksApi(object):
             _request_auth=local_var_params.get('_request_auth'))
 
     def ipblocks_put(self, ipblock_id, ipblock, **kwargs):  # noqa: E501
-        """Modify IP Block  # noqa: E501
+        """Modify IP blocks  # noqa: E501
 
-        You can use update attributes of a resource  # noqa: E501
+        Modify the properties of the specified IP block.  # noqa: E501
         This method makes a synchronous HTTP request by default. To make an
         asynchronous HTTP request, please pass async_req=True
 
         >>> thread = api.ipblocks_put(ipblock_id, ipblock, async_req=True)
         >>> result = thread.get()
 
-        :param ipblock_id: (required)
+        :param ipblock_id: The unique ID of the IP block. (required)
         :type ipblock_id: str
-        :param ipblock: IP Block to be modified (required)
+        :param ipblock: The modified IP block. (required)
         :type ipblock: IpBlock
-        :param pretty: Controls whether response is pretty-printed (with indentation and new lines)
+        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
         :type pretty: bool
-        :param depth: Controls the details depth of response objects.  Eg. GET /datacenters/[ID]  - depth=0: only direct properties are included. Children (servers etc.) are not included  - depth=1: direct properties and children references are included  - depth=2: direct properties and children properties are included  - depth=3: direct properties and children properties and children's children are included  - depth=... and so on
+        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
         :type depth: int
-        :param x_contract_number: Users having more than 1 contract need to provide contract number, against which all API requests should be executed
+        :param x_contract_number: Users with multiple contracts must provide the contract number, against which all API requests are to be executed.
         :type x_contract_number: int
         :param async_req: Whether to execute the request asynchronously.
         :type async_req: bool, optional
@@ -889,24 +889,24 @@ class IPBlocksApi(object):
         return self.ipblocks_put_with_http_info(ipblock_id, ipblock, **kwargs)  # noqa: E501
 
     def ipblocks_put_with_http_info(self, ipblock_id, ipblock, **kwargs):  # noqa: E501
-        """Modify IP Block  # noqa: E501
+        """Modify IP blocks  # noqa: E501
 
-        You can use update attributes of a resource  # noqa: E501
+        Modify the properties of the specified IP block.  # noqa: E501
         This method makes a synchronous HTTP request by default. To make an
         asynchronous HTTP request, please pass async_req=True
 
         >>> thread = api.ipblocks_put_with_http_info(ipblock_id, ipblock, async_req=True)
         >>> result = thread.get()
 
-        :param ipblock_id: (required)
+        :param ipblock_id: The unique ID of the IP block. (required)
         :type ipblock_id: str
-        :param ipblock: IP Block to be modified (required)
+        :param ipblock: The modified IP block. (required)
         :type ipblock: IpBlock
-        :param pretty: Controls whether response is pretty-printed (with indentation and new lines)
+        :param pretty: Controls whether the response is pretty-printed (with indentations and new lines).
         :type pretty: bool
-        :param depth: Controls the details depth of response objects.  Eg. GET /datacenters/[ID]  - depth=0: only direct properties are included. Children (servers etc.) are not included  - depth=1: direct properties and children references are included  - depth=2: direct properties and children properties are included  - depth=3: direct properties and children properties and children's children are included  - depth=... and so on
+        :param depth: Controls the detail depth of the response objects.  GET /datacenters/[ID]  - depth=0: Only direct properties are included; children (servers and other elements) are not included.  - depth=1: Direct properties and children references are included.  - depth=2: Direct properties and children properties are included.  - depth=3: Direct properties and children properties and children's children are included.  - depth=... and so on
         :type depth: int
-        :param x_contract_number: Users having more than 1 contract need to provide contract number, against which all API requests should be executed
+        :param x_contract_number: Users with multiple contracts must provide the contract number, against which all API requests are to be executed.
         :type x_contract_number: int
         :param async_req: Whether to execute the request asynchronously.
         :type async_req: bool, optional
